<?php
$lang['expired_searchable'] = 'Artigos expirados podem aparecer nos resultados na pequisa?';
$lang['helpshowall'] = 'Mostrar todos os arquivos,  independentemente da data final';
$lang['error_invaliddates'] = 'Uma ou mais das datas inscritas eram inv&aacute;lidas';
$lang['notify_n_draft_items_sub'] = '%d Artigos de Not&iacute;cia(s)';
$lang['notify_n_draft_items'] = 'Tem %s n&atilde;o publicado(s)';
$lang['unlimited'] = 'Ilimitado';
$lang['none'] = 'Nenhum';
$lang['anonymous'] = 'An&oacute;nimo';
$lang['unknown'] = 'Desconhecido';
$lang['fesubmit_redirect'] = 'P&aacute;ginaID ou alias por forma a redireccionar ap&oacute;s uma not&iacute;cia ser submetida via ac&ccedil;&atilde;o fesubmit';
$lang['allow_summary_wysiwyg'] = 'Permitir o uso do Editor de Textos no campo do sum&aacute;rio';
$lang['title_browsecat_template'] = 'Editor Template Navegador de Categorias ';
$lang['title_browsecat_sysdefault'] = 'Template Padr&atilde;o Navegador de Categorias ';
$lang['browsecattemplate'] = 'Templates Categorias';
$lang['error_filesize'] = 'Um arquivo enviado excedeu o tamanho m&aacute;ximo permitido';
$lang['post_date_desc'] = 'Data Descendente';
$lang['post_date_asc'] = 'Data Ascendente';
$lang['expiry_date_desc'] = 'Data de Expira&ccedil;&atilde;o Descendente';
$lang['expiry_date_asc'] = 'Data de Expira&ccedil;&atilde;o Ascendente';
$lang['title_desc'] = 'Titulo Descendente';
$lang['title_asc'] = 'Titulo Ascendente';
$lang['status_desc'] = 'Estado Descendente';
$lang['status_asc'] = 'Estado Ascendente';
$lang['fesubmit_status'] = 'O Estado das not&iacute;cias submetidas via frontend';
$lang['error_invalidfiletype'] = 'N&atilde;o &eacute; poss&iacute;vel carregar esse tipo de arquivo';
$lang['error_upload'] = 'Ocorreu um problema no carregamento de um arquivo';
$lang['error_movefile'] = 'N&atilde;o foi poss&iacute;vel criar o arquivo: %s';
$lang['error_mkdir'] = 'N&atilde;o foi poss&iacute;vel criar a pasta: %s';
$lang['expiry_interval'] = 'O n&uacute;mero de dias (por padr&atilde;o) antes de expirar um artigo (se for seleccionado para expirar)';
$lang['removed'] = 'Removido';
$lang['msg_contenttype_removed'] = 'O conte&uacute;do das not&iacute;cias foi removido. Por favor, coloque <code>{news}</code> tags com os par&acirc;metros adequados na sua p&aacute;gina ou template para substituir essa funcionalidade.';
$lang['delete_selected'] = 'Eliminar Not&iacute;cias Seleccionadas';
$lang['areyousure_deletemultiple'] = 'Tem a certeza que pretende eliminar todos os tens seleccionados?\nCom esta opera&ccedil;&atilde;o remove para sempre!';
$lang['error_templatenamexists'] = 'J&aacute; existe um template com esss nome';
$lang['error_noarticlesselected'] = 'N&atilde;o foram Selecionados Artigos';
$lang['reassign_category'] = 'Alterar Categoria Para';
$lang['select'] = 'Seleccionar';
$lang['approve'] = 'Defenir Status para &#039;P&uacute;blicado&#039;';
$lang['revert'] = 'Defenir Status para &#039;Rascunho&#039;';
$lang['hide_summary_field'] = 'Esconder o campo sum&aacute;rio quando adicionar ou editar artigos';
$lang['textbox'] = 'Campo de Texto';
$lang['checkbox'] = 'Campo de Verifica&ccedil;&atilde;o';
$lang['textarea'] = '&Aacute;rea de Texto';
$lang['file'] = 'Arquivo';
$lang['auto_create_thumbnails'] = 'Automaticamente criar Miniatura para arquivos com essas extens&otilde;es';
$lang['allowed_upload_types'] = 'Permitir somente arquivos com essas extens&otilde;es';
$lang['fielddefupdated'] = 'Campo actualizado';
$lang['editfielddef'] = 'Editar Campo';
$lang['up'] = 'Cima';
$lang['down'] = 'Baixo';
$lang['fielddefdeleted'] = 'Campo eliminado';
$lang['nameexists'] = 'Um campo com este nome j&aacute; existe';
$lang['notanumber'] = 'O comprimento m&aacute;ximo n&atilde;o &eacute; um n&uacute;mero';
$lang['fielddef'] = 'Defini&ccedil;&atilde;o Campo';
$lang['fielddefadded'] = 'Campo adicionado com sucesso';
$lang['public'] = 'P&uacute;blico';
$lang['type'] = 'Tipo';
$lang['info_maxlength'] = 'O comprimento m&aacute;ximo, aplica-se apenas &agrave; introdu&ccedil;&atilde;o de campos de texto.';
$lang['maxlength'] = 'Comprimento M&aacute;ximo';
$lang['addfielddef'] = 'Adicionar Campo';
$lang['customfields'] = 'Defini&ccedil;&otilde;es do Campo';
$lang['deprecated'] = 'N&atilde;o suportado';
$lang['subject_newnews'] = 'Um novo artigo foi submetido';
$lang['email_subject'] = 'O assunto do e-mail de sa&iacute;da';
$lang['email_template'] = 'O formato da mensagem de e-mail';
$lang['formsubmit_emailaddress'] = 'E-mail para receber notifica&ccedil;&atilde;o da not&iacute;cia';
$lang['extra'] = 'Campo Extra';
$lang['uploadscategory'] = 'Carregar Categoria';
$lang['title_available_templates'] = 'Templates Dispon&iacute;veis';
$lang['resettodefault'] = 'Redefinir para o Padr&atilde;o';
$lang['title_form_template'] = 'Formul&aacute;rio Template';
$lang['title_detail_template'] = 'Detalhes Template';
$lang['title_summary_template'] = 'Sum&aacute;rio Template';
$lang['prompt_templatename'] = 'Template Nome';
$lang['prompt_template'] = 'Template Fonte';
$lang['title_form_sysdefault'] = 'Padr&atilde;o Form Template';
$lang['title_summary_sysdefault'] = 'Padr&atilde;o Sum&aacute;rio Template';
$lang['title_detail_sysdefault'] = 'Padr&atilde;o Detalhes Template';
$lang['info_sysdefault2'] = 'Esta TAB cont&eacute;m &aacute;reas de texto para permitir que edite um conjunto de templates que s&atilde;o exibidos quando criar um &#039;novo&#039; template. Mude o conte&uacute;do, e clicando no bot&atilde;o &quot;enviar&quot;<strong>n&atilde;o ter&aacute; qualquer efeito nos actuais </strong>.';
$lang['info_sysdefault'] = '(o conte&uacute;do utilizado por defeito quando se cria um novo template)';
$lang['template'] = 'Template ';
$lang['prompt_name'] = 'Nome';
$lang['prompt_default'] = 'Padr&atilde;o';
$lang['prompt_newtemplate'] = 'Criar Novo Template';
$lang['help_pagelimit'] = 'N&uacute;mero m&aacute;ximo de itens para visualiza&ccedil;&atilde;o (por p&aacute;gina). Se este par&acirc;metro n&atilde;o for fornecido todos os itens correspondentes ser&atilde;o exibidos. Se assim &eacute;, e h&aacute; mais itens dispon&iacute;veis do que o especificado no par&acirc;metro, textos e links ser&atilde;o fornecidos para permitir  percorrer os resultados';
$lang['prompt_page'] = 'P&aacute;gina';
$lang['firstpage'] = '<< ';
$lang['prevpage'] = '< ';
$lang['nextpage'] = ' >';
$lang['lastpage'] = ' >>';
$lang['prompt_of'] = 'de';
$lang['prompt_pagelimit'] = 'P&aacute;gina Limite';
$lang['prompt_sorting'] = 'Ordenar por';
$lang['title_filter'] = 'Filtros';
$lang['published'] = 'P&uacute;blicado';
$lang['draft'] = 'Rascunho';
$lang['expired'] = 'Expirar';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Restaurar para padr&atilde;o';
$lang['restoretodefaultsmsg'] = 'Esta opera&ccedil;&atilde;o ir&aacute; restaurar o template do seu sistema para o padr&atilde;o. Tem certeza de que deseja prosseguir?';
$lang['addarticle'] = 'Adicionar Not&iacute;cia ';
$lang['articleadded'] = 'A Not&iacute;cia foi adicionado com sucesso.';
$lang['articleupdated'] = 'A Not&iacute;cia  foi actualizado com sucesso.';
$lang['articledeleted'] = 'A Not&iacute;cia  foi eliminado com sucesso.';
$lang['addcategory'] = 'Adicionar Categoria';
$lang['categoryadded'] = 'A categoria foi adicionada com sucesso.';
$lang['categoryupdated'] = 'A categoria foi actualizada com sucesso.';
$lang['categorydeleted'] = 'A categoria foi eliminada com sucesso.';
$lang['addnewsitem'] = 'Adicionar Not&iacute;cia';
$lang['allcategories'] = 'Todas as Categorias';
$lang['allentries'] = 'Todas as Entradas';
$lang['areyousure'] = 'Tem certeza que quer eliminar?';
$lang['articles'] = 'Not&iacute;cias ';
$lang['cancel'] = 'Cancelar';
$lang['category'] = 'Categoria';
$lang['categories'] = 'Categorias';
$lang['default_category'] = 'Categoria Padr&atilde;o';
$lang['content'] = 'Conte&uacute;do';
$lang['dateformat'] = '%s n&atilde;o em um v&aacute;lido yyyy-mm-dd hh:mm:ss formato';
$lang['delete'] = 'Remover';
$lang['description'] = 'Adicionar, editar e remover Not&iacute;cias';
$lang['formtemplate'] = 'Templates Form ';
$lang['detailtemplate'] = 'Templates Detalhes ';
$lang['default_templates'] = 'Templates Padr&atilde;o';
$lang['detailtemplateupdated'] = 'A actualiza&ccedil;&atilde;o do Templates Detalhes  foi salvo com &ecirc;xito.';
$lang['displaytemplate'] = 'Mostrar Template';
$lang['edit'] = 'Editar';
$lang['enddate'] = 'Data final';
$lang['endrequiresstart'] = 'Introduzir uma data final exige tamb&eacute;m uma data de in&iacute;cio';
$lang['entries'] = '%s Entradas';
$lang['status'] = 'Estado';
$lang['expiry'] = 'Expira&ccedil;&atilde;o';
$lang['filter'] = 'Filtro';
$lang['more'] = 'Mais';
$lang['category_label'] = 'Categoria:';
$lang['author_label'] = 'Inserida por:';
$lang['moretext'] = 'Texto Mais';
$lang['name'] = 'Nome';
$lang['news'] = 'Not&iacute;cias ';
$lang['news_return'] = 'Voltar';
$lang['newcategory'] = 'Nova Categoria';
$lang['needpermission'] = 'Necessita da &#039;%s&#039; permiss&atilde;o para executar essa fun&ccedil;&atilde;o.';
$lang['nocategorygiven'] = 'Tem inserir uma Categoria';
$lang['startdatetoolate'] = 'A data de in&iacute;cio &eacute; tarde demais (depois da data final?)';
$lang['nocontentgiven'] = 'Tem inserir um conte&uacute;do';
$lang['noitemsfound'] = '<strong>Sem</strong> items encontrados para esta categoria: %s';
$lang['nopostdategiven'] = 'Tem inserir uma data';
$lang['note'] = '<em>Note:</em> Dates must be in a &#039;yyyy-mm-dd hh:mm:ss&#039; format.';
$lang['notitlegiven'] = 'Tem inserir um Titulo';
$lang['nonamegiven'] = 'Tem inserir um Nome';
$lang['numbertodisplay'] = 'N&uacute;mero a mostrar (vazia mostra todos os dados)';
$lang['print'] = 'Imprimir';
$lang['postdate'] = 'Data da Submiss&atilde;o';
$lang['postinstall'] = 'Certifique-se de definir a  permiss&atilde;o &quot;Modificar Not&iacute;cias&quot;  para os usu&aacute;rios que dever&atilde;o administrar Not&iacute;cias.';
$lang['selectcategory'] = 'Seleccionar Categoria';
$lang['showchildcategories'] = 'Mostrar Sub Categorias';
$lang['sortascending'] = 'Ordena&ccedil;&atilde;o Ascendente';
$lang['startdate'] = 'Data de Inicio';
$lang['startoffset'] = 'Come&ccedil;ar a exibir o item en&eacute;simo';
$lang['startrequiresend'] = 'Introduzir uma data de in&iacute;cio exige tamb&eacute;m uma data de final';
$lang['submit'] = 'Submeter';
$lang['summary'] = 'Sum&aacute;rio';
$lang['summarytemplate'] = 'Templates Sum&aacute;rio';
$lang['summarytemplateupdated'] = 'Template Sum&aacute;rio foi actualizado.';
$lang['title'] = 'T&iacute;tulo';
$lang['options'] = 'Op&ccedil;&otilde;es';
$lang['optionsupdated'] = 'Op&ccedil;&otilde;es Actualizadas com Sucesso.';
$lang['useexpiration'] = 'Usar Data de Expira&ccedil;&atilde;o';
$lang['eventdesc-NewsArticleAdded'] = 'Enviado quando um artigo &eacute; adicionado.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Enviado quando um artigo &eacute; editado.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Enviado quando um artigo &eacute; eliminado.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;news_id&quot; - Id of the news article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Enviado quando uma categoria &eacute; adicionada.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id&quot; - Id of the news category</li>
<li>&quot;name&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Enviado quando uma categoria &eacute; editada.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id&quot; - Id of the news category</li>
<li>&quot;name&quot; - Name of the news category</li>
<li>&quot;origname&quot; - The original name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Enviado quando uma categoria &eacute; eliminada.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id&quot; - Id of the deleted category </li>
<li>&quot;name&quot; - Name of the deleted category</li>
</ul>
';
$lang['help_articleid'] = 'This parameter is only applicable to the detail view.  It allows specifying which news article to display in detail mode.  If the special value -1 is used, the system will display the newest, published, non expired article. ';
$lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de itens a exibir =- deixando este vazio ir&aacute; mostrar todos os itens.';
$lang['helpstart'] = 'Comece com o en&eacute;simo item - deixando vazio ter&atilde;o in&iacute;cio no primeiro item.';
$lang['helpcategory'] = 'Used in the summary view to display only items for the specified categories. <b>Use * after the name to show children.</b>  Multiple categories can be used if separated with a comma. Leaving empty, will show all categories.  This parameter also works for the frontend submit action, however only a single category name is supported. ';
$lang['helpmoretext'] = 'Text to display at the end of a news item if it goes over the summary length.  Defaults to &quot;more...&quot;';
$lang['helpsummarytemplate'] = 'Use a separate database template for displaying the article summary.  This template must exist and be visible in the summary template tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used. ';
$lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used. ';
$lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used. ';
$lang['helpdetailtemplate'] = 'Use a separate database template for displaying the article detail. This template must exist and be visible in the detail template tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used. ';
$lang['helpsortby'] = 'Field to sort by.  Options are: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  Defaults to &quot;news_date&quot;. If &quot;random&quot; is specified, the sortasc param is ignored.';
$lang['helpsortasc'] = 'Sort news items in ascending date order rather than descending. ';
$lang['helpdetailpage'] = 'Page to display News details in.  This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary. ';
$lang['helpshowarchive'] = 'Mostrar apenas not&iacute;cias que expiraram.';
$lang['helpbrowsecat'] = 'Mostra uma lista das categorias.';
$lang['helpaction'] = 'Override the default action.  Possible values are:
<ul>
<li>&amp;quot;detail&amp;quot; - to display a specified articleid in detail mode.</li>
<li>&amp;quot;default&amp;quot; - to display the summary view</li>
<li>&amp;quot;fesubmit&amp;quot; - to display the frontend form for allowing users to submit news articles on the front end.</li>
<li>&amp;quot;browsecat&amp;quot; - to display a browseable category list.</li>
</ul>';
$lang['help'] = '<h3>Important Notes</h3>
<p>Version 2.9 and greater of News has removed the formatpostdate member from the templates, and has also removed the dateformat parameter.  You should be using the cms_date_format modifier (as indicated in the default templates) to format dates, and should be using entry->postdate instead of entry->formatpostdate in your templates.</p>
<h3>What does this do?</h3>
<p>News is a module for displaying news events on your page, similar to a blog style, except with more features!.  When the module is installed, a News admin page is added to administration menu that will allow you to select or add a news category.  Once a news category is created or selected, a list of news items for that category will be displayed.  From here, you can add, edit or delete news items for that category.</p>
<h4>Numerous display methods</h4>
<p>The parameters supported by the news module, and support for numerous templates of each time mean that your options for displaying news articles are limitless.</p>
<h4>Custom Fields</h4>
<p>The News module allows defining numerous custom fields (including files and images) that will allow you to attach pdf files or numerous images to your articles.</p>
        <h4>Categories</h4>
	<p>News supplies a hierarchical category mechanism for organizing your articles.  A news article can only be in one place in the hierarchy.</p>
	<h4>Expiry and Status</h4>
	<p>Each news article can have an optional expiry date, after which it will not be shown on your web page.  As well, articles can be marked as <em>draft</em> to remove them permanently from your web page.</p>
	<h3>Security</h3>
	<p>The user must belong to a group with the &#039;Modify News&#039; permission in order to add or edit News entries.</p>
        <p>As well, In order to delete news entries, the user must belong to a group with the &#039;Delete News Articles&#039; permission.</p>
	<p>In order to edit the layout templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>
	<p>In order to edit the global news preferences, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>
	<p>Additionally, to approve news for frontend display the user must belong to a group with the &#039;Approve News&#039; permission.</p>
	<h3>How do I use it?</h3>
	<p>The easiest way to use it is with the {news} wrapper tag (wraps the module in a tag, to simplify the syntax).  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{news number=&#039;5&#039;}</code></p>
<h3>Templates</h3>
<p>Since version 2.3 News supports multiple database templates, and no longer supports additional file templates.  Users who used the old file template system should follow these steps (for each file template):</p>
<ul>
<li>Copy the file template into the clipboard</li>
<li>Create a new database template <em>(either summary or detailed as required)</em>.  Give the new template the same name (including the .tpl extension) as the old file template, and paste the contents.</li>
<li>Hit Submit</li>
</ul>
<p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
$lang['qca'] = 'P0-1091236660-1271519106143';
$lang['utma'] = '156861353.1066088901.1271528668.1271873862.1272120553.10';
$lang['utmz'] = '156861353.1271618958.6.4.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,43343.0.html';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>